
# Type: sensitivity quantifier




URI: [biolink:SensitivityQuantifier](https://w3id.org/biolink/vocab/SensitivityQuantifier)


![img](http://yuml.me/diagram/nofunky;dir:TB/class/[RelationshipQuantifier]^-[SensitivityQuantifier])

## Parents

 *  is_a: [RelationshipQuantifier](RelationshipQuantifier.md)

## Attributes

